@@ -249,6 +249,20 @@ def test_mnprofile():
     m.migrad()
     m.mnprofile('y')
 
+@raises(RuntimeError)
+def test_printfmin_uninitialized():
+    #issue 85
+    def f(x): return 2 + 3 * x
+    fitter = Minuit(f)
+    fitter.print_fmin()
+
+@raises(ValueError)
+def test_reverse_limit():
+    #issue 94
+    def f(x,y,z):
+        return (x-2)**2 + (y-3)**2 + (z-4)**2
+    m = Minuit(f, limit_x=(3., 2.))
+    m.migrad()
 
 class TestErrorMatrix(TestCase):
 
